@@ -1,6 +1,10 @@
-#' Select data from the DWD CDC FTP Server
+#' @title Select data from the DWD CDC FTP Server
 #' 
-#' Select files for downloading with \code{\link{dataDWD}}.
+#' @description Select files for downloading with \code{\link{dataDWD}}.\cr
+#' The available folders with datasets are listed at
+#' \url{https://bookdown.org/brry/rdwd/available-datasets.html}.
+#' To use an updated index (if necessary), see 
+#' \url{https://bookdown.org/brry/rdwd/station-selection.html#fileindex}.\cr\cr
 #' All arguments (except for \code{mindex}, \code{findex} and \code{base})
 #' can be a vector and will be recycled to the maximum length of all arguments.
 #' If that length > 1, the output is a list of filenames (or vector if \code{outvec=TRUE}).\cr
@@ -21,56 +25,12 @@
 #' For case 3 and 4 (\bold{path} given), you can set \code{meta=TRUE}.
 #' Then selectDWD will return the name of the station description file at \bold{path}.
 #' This is why case 3 with \code{meta=FALSE} only returns the data file names (ending in .zip).\cr\cr\cr
-#' The following folders in \bold{\code{res/var/per}} notation
-#' (resolution/variable/period) are available at \code{\link{dwdbase}}:\cr
-#' "<" signifies a split into the folders \code{per} = "recent" and "historical".\cr
-#' "<<" signifies a split into the folders \code{per} = "now", recent", "historical" and "meta_data".\cr
-#' "-" signifies that there are no further sub-folders. \cr
-#' Please note that both "solar" (-/<<) and "sun" (<) are available!
-#' \tabular{lllll}{
-#' \code{res}=\bold{10_minutes} \tab | \code{res}=\bold{hourly} \tab | \code{res}=\bold{daily} \tab | \code{res}=\bold{monthly} \tab | \code{res}=\bold{annual} \cr
-#' \code{var=}            \tab                      \tab                      \tab                 \tab                 \cr
-#'                        \tab |                    \tab | kl <               \tab | kl <          \tab | kl <          \cr
-#'                        \tab |                    \tab | more_precip <      \tab | more_precip < \tab | more_precip < \cr
-#' air_temperature <<     \tab | air_temperature <  \tab |                    \tab |               \tab |               \cr
-#' extreme_temperature << \tab |                    \tab |                    \tab |               \tab |               \cr
-#' extreme_wind <<        \tab |                    \tab |                    \tab |               \tab |               \cr
-#'                        \tab | cloudiness <       \tab |                    \tab |               \tab |               \cr
-#'                        \tab | cloud_type <       \tab |                    \tab |               \tab |               \cr
-#'                        \tab | dew_point <        \tab |                    \tab |               \tab |               \cr
-#' precipitation <<       \tab | precipitation <    \tab |                    \tab |               \tab |               \cr
-#'                        \tab | pressure <         \tab |                    \tab |               \tab |               \cr
-#'                        \tab | soil_temperature < \tab | soil_temperature < \tab |               \tab |               \cr
-#' solar <<               \tab | solar -            \tab | solar -            \tab |               \tab |               \cr
-#'                        \tab | sun <              \tab |                    \tab |               \tab |               \cr
-#'                        \tab | visibility <       \tab |                    \tab |               \tab |               \cr
-#'                        \tab |                    \tab | water_equiv <      \tab |               \tab |               \cr
-#' wind <<                \tab | wind <             \tab |                    \tab |               \tab |               \cr
-#'                        \tab | wind_synop <       \tab |                    \tab |               \tab |               \cr
-#' }
-#' Please note that \code{1_minute/precipitation/historical} has subfolders for each year.
-#' \tabular{lll}{
-#' \code{res}=\bold{1_minute} \tab | \code{res}=\bold{multi_annual} \tab | \code{res}=\bold{subdaily} \cr 
-#' \code{var=}      \tab                \tab                     \cr
-#' precipitation << \tab |              \tab |                   \cr
-#'                  \tab | mean_61-90 - \tab |                   \cr
-#'                  \tab | mean_71-00 - \tab |                   \cr
-#'                  \tab | mean_81-10 - \tab |                   \cr
-#'                  \tab |              \tab | air_temperature < \cr
-#'                  \tab |              \tab | cloudiness <      \cr
-#'                  \tab |              \tab | moisture <        \cr
-#'                  \tab |              \tab | pressure <        \cr
-#'                  \tab |              \tab | soil <            \cr
-#'                  \tab |              \tab | standard_format - \cr
-#'                  \tab |              \tab | visibility <      \cr
-#'                  \tab |              \tab | wind <            \cr
-#' }
 #' 
 #' @return Character string with file path and name(s) in the format
 #'         "base/res/var/per/filename.zip"
 #' @author Berry Boessenkool, \email{berry-b@@gmx.de}, Oct 2016
-#' @seealso \code{\link{dataDWD}}, \code{\link{metaIndex}}, \url{../doc/mapDWD.html},
-#'          \code{vignette("mapDWD", package="rdwd")}
+#' @seealso \code{\link{dataDWD}}, \code{\link{metaIndex}},
+#'          \url{https://bookdown.org/brry/rdwd}
 #' @keywords file
 #' @importFrom berryFunctions truncMessage traceCall
 #' @importFrom utils menu
@@ -130,6 +90,7 @@
 #'              with \code{\link{==}})? Else with \code{\link{grepl}}. DEFAULT: TRUE
 #' @param mindex Single object: Index with metadata passed to \code{\link{findID}}.
 #'              DEFAULT: \code{rdwd:::\link{metaIndex}}
+#' @param quiet Suppress id length warnings?
 #' @param id    Char/Number: station ID with or without leading zeros, e.g. "00614" or 614.
 #'              Is internally converted to an integer, because some DWD meta data
 #'              files also contain no leading zeros. DEFAULT: findID(name, exaxtmatch, mindex)
@@ -155,7 +116,7 @@
 #'              instead of a list, return a vector? (via \code{\link{unlist}}).
 #'              DEFAULT: \code{per \%in\% c("rh","hr")}
 #' @param \dots Further arguments passed to \code{\link{indexFTP}} if \code{current=TRUE},
-#'              like dir, quiet
+#'              except folder and base.
 #' 
 selectDWD <- function(
 name="",
@@ -164,7 +125,8 @@ var=NA,
 per=NA,
 exactmatch=TRUE,
 mindex=metaIndex,
-id=findID(name, exactmatch=exactmatch, mindex=mindex),
+quiet=FALSE,
+id=findID(name, exactmatch=exactmatch, mindex=mindex, quiet=quiet),
 base=dwdbase,
 findex=fileIndex,
 current=FALSE,
@@ -219,15 +181,14 @@ per[substr(per,1,1)=="h"] <- "historical"
 per[substr(per,1,1)=="r"] <- "recent"
 # solar per to ""
 per[var=="solar" & res %in% c("hourly","daily")] <- ""
-per[var=="standard_format" & res=="subdaily"] <- ""
 # multiannual data has no id, remove if given:
 rma <- res=="multi_annual"
-if(any(rma))
+if(any(rma, na.rm=TRUE))
   {
-  if(any(id[rma]!="")) warning(traceCall(1, "", ": "), "multi_annual data is not ", 
+  if(any(id[rma]!="", na.rm=TRUE)) warning(traceCall(1, "", ": "), "multi_annual data is not ", 
       "organized by station ID. Setting id to ''.", call.=FALSE)
   id[rma] <- ""
-  if(any(per[rma]!="")) warning(traceCall(1, "", ": "), "multi_annual data is not ", 
+  if(any(per[rma]!="", na.rm=TRUE)) warning(traceCall(1, "", ": "), "multi_annual data is not ", 
       "organized in period folders. Setting per to ''.", call.=FALSE)
   per[rma] <- ""
   }
@@ -242,7 +203,7 @@ if(current)
   uniquepaths <- uniquepaths[uniquepaths!="///"]
   if(length(uniquepaths)<1) stop(traceCall(1, "in ", ": "),
                     "current=TRUE, but no valid paths available.", call.=FALSE)
-  findex <- createIndex(indexFTP(uniquepaths, ...), fname="")
+  findex <- createIndex(indexFTP(folder=uniquepaths, base=base, quiet=quiet, ...), fname="")
   findexname <- "currentIndex"
   }
 # convert ID to integer:
@@ -317,12 +278,11 @@ if(givenid & !givenpath)
   filename <- findex[findex$id %in% id[i], "path"]
   filename <- filename[!is.na(filename)]
   # check output length
-  if(length(filename)<1) warning(traceCall(3, "", ": "), "in file index '", findexname,
-                                 "', no filename could be detected with ID ",
-                                 id[i], ".", call.=FALSE)
-  if(length(filename)>1) warning(traceCall(3, "", ": "), "in file index '", findexname,
-                                 "', there are ", length(filename), " files with ID ",
-                                 id[i], ".", call.=FALSE)
+  if(length(filename)<1 & !quiet) warning(traceCall(3, "", ": "), "in file index '", 
+     findexname, "', no filename could be detected with ID ", id[i], ".", call.=FALSE)
+  if(length(filename)>1 & !quiet) warning(traceCall(3, "", ": "), "in file index '", 
+     findexname, "', there are ", length(filename), " files with ID ",id[i], ".", 
+     call.=FALSE)
   return(   paste0(base,"/",filename)   )
   }
 #
